@@ -3,14 +3,16 @@
 #   Copyright EAVISE
 #
 
-__all__ = ['data', 'engine', 'models', 'network', 'prune']
+__all__ = ['data', 'engine', 'models', 'network', 'prune', 'util']
 
-
-from .version import __version__
-from .log import *
+from ._log import *
 
 from . import data
 from . import engine
 from . import models
 from . import network
 from . import prune
+from . import util
+
+from . import _version
+__version__ = _version.get_versions()['version']
