@@ -2,8 +2,10 @@
 #   Lightnet optional dependencies
 #   Copyright EAVISE
 #
+import warnings
 import logging
 
+
 __all__ = [
     'bb',
     'cv2',
@@ -11,38 +13,36 @@ __all__ = [
     'ImageOps',
     'onnx',
     'onnx_numpy_helper',
-    'pd',
     'pgpd',
     'pygeos',
     'tqdm',
 ]
 log = logging.getLogger(__name__)
 
+
 try:
-    import pandas as pd
     import brambox as bb
 except ModuleNotFoundError:
-    log.warning('Brambox is not installed and thus all data functionality related to it cannot be used')
-    pd = None
+    warnings.warn('Brambox is not installed and thus all data functionality related to it cannot be used', category=ImportWarning)
     bb = None
 
 try:
     import cv2
 except ModuleNotFoundError:
-    log.warning('OpenCV is not installed and cannot be used')
+    warnings.warn('OpenCV is not installed and cannot be used', category=ImportWarning)
     cv2 = None
 
 try:
     from PIL import Image, ImageOps
 except ModuleNotFoundError:
-    log.warning('Pillow is not installed and cannot be used')
+    warnings.warn('Pillow is not installed and cannot be used', category=ImportWarning)
     Image, ImageOps = None, None
 
 try:
     import onnx
     from onnx import numpy_helper as onnx_numpy_helper
 except ModuleNotFoundError:
-    log.warning('ONNX is not installed and thus no pruning functionality will work')
+    warnings.warn('ONNX is not installed and thus no pruning functionality will work', category=ImportWarning)
     onnx = None
     onnx_numpy_helper = None
 
@@ -50,6 +50,7 @@ try:
     import pygeos
     import pgpd
 except ModuleNotFoundError:
+    warnings.warn('PyGEOS and PyGEOS-Pandas are not installed and thus no instance segmentation functionality will work', category=ImportWarning)
     pygeos = None
     pgpd = None
 
