@@ -4,14 +4,15 @@
 #
 import random
 import logging
-import collections
+from collections.abc import Mapping, Sequence
 from functools import wraps
+import pandas as pd
 import torch
 from torch.utils.data.dataset import Dataset as torchDataset
 from torch.utils.data.sampler import BatchSampler as torchBatchSampler
 from torch.utils.data.dataloader import DataLoader as torchDataLoader
 from torch.utils.data.dataloader import default_collate
-from lightnet._imports import pd, bb
+from lightnet._imports import bb
 
 
 __all__ = ['Dataset', 'DataLoader', 'brambox_collate']
@@ -228,12 +229,12 @@ def brambox_collate(batch):
         else:
             return pd.concat(batch, ignore_index=True, sort=False)
     # Copied from torch.utils.data.dataloader.default_collate
-    elif isinstance(elem, collections.abc.Mapping):
+    elif isinstance(elem, Mapping):
         return {key: brambox_collate([d[key] for d in batch]) for key in elem}
     elif isinstance(elem, tuple) and hasattr(elem, '_fields'):  # namedtuple
         elem_type = type(elem)
         return elem_type(*(brambox_collate(samples) for samples in zip(*batch)))
-    elif isinstance(elem, collections.abc.Sequence) and not isinstance(elem, (str, bytes)):
+    elif isinstance(elem, Sequence) and not isinstance(elem, (str, bytes)):
         it = iter(batch)
         elem_size = len(next(it))
         if not all(len(elem) == elem_size for elem in it):
