@@ -5,8 +5,8 @@
 import logging
 import numpy as np
 import torch.nn as nn
-import brambox as bb
-from lightnet._imports import pd
+import pandas as pd
+from lightnet._imports import bb
 
 __all__ = ['TensorToBrambox', 'PolygonizeMask']
 log = logging.getLogger(__name__)
@@ -18,19 +18,62 @@ class TensorToBrambox(nn.Module):
 
     Args:
         class_label_map (list, optional): List of class labels to transform the class id's in actual names; Default **None**
-        image_map (list, optional): List of image to transform the batch numbers in actual image names; Default **None**
+        image_map (list, optional): **DEPRECATED** List of image to transform the batch numbers in actual image names; Default **None**
 
     Returns:
         pandas.DataFrame:
             brambox detection dataframe where the `image` column contains the batch number (int column from 1st tensor column).
 
+    Note:
+        By default, this transformation will return the image number of the batch as the image columns.
+
+        Previously, we used the `image_map` argument to convert that column to a proper brambox categorical.
+        However, this requires carefull handling of the batch number, as this number starts from zero for each new batch.
+        Additionally, this only works when looping through your dataset in the same order as the `image_map`.
+
+        .. doctest::
+            :options: +SKIP
+
+            >>> post = ln.data.transform.TensorToBrambox(
+            ...     class_label_map=['person', 'dog'],
+            ...     image_map=['img1', 'img2', 'img3', 'img4', 'img5']
+            ... )
+            >>> processed_images = 0
+            >>> detections = []
+            >>> for data, annos in dataloader:
+            ...     # Run network
+            ...     output = network(data)
+            ...     # Increase batch number
+            ...     output[:, 0] += processed_images
+            ...     processed_images += data.shape[0]
+            ...     # Run post-processing
+            ...     detections.append(post(output))
+            >>> # Combine detections
+            >>> detections = bb.util.concat(detections, sort=False, ignore_index=True)
+
+        Our new methodology assumes that you correctly filtered the images of the annotations in your dataset (eg. :func:`brambox.util.select_images`).
+        If that is the case, you can simply copy the data-type of your annotations to the detections.
+        This works even if you shuffle the dataset and also works with :class:`~lightnet.data.transform.Compose`, by passing `image_dtype` as a keyword argument.
+
+        .. doctest::
+            :options: +SKIP
+
+            >>> post = ln.data.transform.TensorToBrambox(class_label_map=['person', 'dog'])
+            >>> detections = []
+            >>> for data, annos in dataloader:
+            ...     # Run network
+            ...     output = network(data)
+            ...     # Run post-processing
+            ...     detections.append(post(output, image_dtype=annos['image'].dtype))
+            >>> # Combine detections
+            >>> detections = bb.util.concat(detections, sort=False, ignore_index=True)
+
     Note:
         Just like everything in PyTorch, this transform only works on batches of images.
         This means you need to wrap your tensor of detections in a list if you want to run this transform on a single image.
 
     Warning:
         If no `class_label_map` is given, this transform will simply convert the class id's to a string.
-        If no `image_map` is given, this transform will simply convert the batch numbers to integers.
     """
     def __init__(self, class_label_map=None, image_map=None):
         super().__init__()
@@ -38,14 +81,25 @@ class TensorToBrambox(nn.Module):
         self.image_map = image_map
         if self.class_label_map is None:
             log.warning('No class_label_map given. The indexes will be used as class_labels.')
-        if self.image_map is None:
-            log.warning('No image_map given. The batch numbers will be used for the image column.')
+        if image_map is not None:
+            import warnings
+            warnings.warn(
+                'image_map is deprecated. Check out the documentation for how to use image_dtype instead.',
+                category=DeprecationWarning,
+                stacklevel=2,
+            )
 
-    def forward(self, boxes, masks=None):
+    def forward(self, boxes, *, masks=None, image_dtype=None):
         if boxes.numel() == 0:
             df = pd.DataFrame(columns=['image', 'class_label', 'id', 'x_top_left', 'y_top_left', 'width', 'height', 'confidence'])
-            df.image = df.image.astype(int)
             df.class_label = df.class_label.astype(str)
+
+            df.image = df.image.astype(int)
+            if image_dtype is not None:
+                df['image'] = pd.Categorical.from_codes(df['image'], dtype=image_dtype)
+            elif self.image_map is not None:
+                df['image'] = pd.Categorical.from_codes(df['image'], categories=self.image_map)
+
             if masks is not None:
                 df['segmentation'] = None
             return df
@@ -69,13 +123,15 @@ class TensorToBrambox(nn.Module):
 
         # Setup class labels
         if self.class_label_map is not None:
-            df.class_label = df.class_label.map({i: v for i, v in enumerate(self.class_label_map)})
+            df['class_label'] = df['class_label'].map({i: v for i, v in enumerate(self.class_label_map)})
         else:
-            df.class_label = df.class_label.astype(str)
+            df['class_label'] = df['class_label'].astype(str)
 
         # Setup image column
-        if self.image_map is not None:
-            df.image = pd.Categorical.from_codes(df.image, categories=self.image_map)
+        if image_dtype is not None:
+            df['image'] = pd.Categorical.from_codes(df['image'], dtype=image_dtype)
+        elif self.image_map is not None:
+            df['image'] = pd.Categorical.from_codes(df['image'], categories=self.image_map)
 
         return df[cols]
 
