@@ -48,7 +48,12 @@ class NMS(nn.Module):
     def __init__(self, iou_thresh, *, class_nms=True, memory_limit=50000, reset_index=True, force_cpu=None, box_type=None):
         super().__init__()
         if force_cpu is not None:
-            log.deprecated('The "force_cpu" argument is deprecated, as Lightnet now uses the cuda implementation of NMS from the torchvision package, which does not need this flag.')
+            import warnings
+            warnings.warn(
+                'The "force_cpu" argument is deprecated, as Lightnet now uses the cuda implementation of NMS from the torchvision package, which does not need this flag.',
+                category=DeprecationWarning,
+                stacklevel=2,
+            )
 
         self.iou_thresh = iou_thresh
         self.class_nms = class_nms
@@ -97,7 +102,8 @@ class NMS(nn.Module):
         categories = boxes[:, 0].clone()
         if self.class_nms:
             classes = boxes[:, -1]
-            categories = categories * classes.max() + classes
+            classes_max = classes.max() + 1
+            categories = categories * classes_max + classes
 
         return batched_nms(coords, boxes[:, -2], categories, self.iou_thresh)
 
@@ -137,8 +143,8 @@ class NMS(nn.Module):
             same_class = (classes[None, ...] == classes[..., None])
             conflicting = (conflicting & same_class)
 
-        keep = np.zeros(conflicting.shape[0], dtype=np.bool)
-        supress = np.zeros(conflicting.shape[0], dtype=np.bool)
+        keep = np.zeros(conflicting.shape[0], dtype=bool)
+        supress = np.zeros(conflicting.shape[0], dtype=bool)
         for i, row in enumerate(conflicting):
             if not supress[i]:
                 keep[i] = True
@@ -148,7 +154,12 @@ class NMS(nn.Module):
 
 
 def NMSFast(*args, **kwargs):
-    log.deprecated('Lightnet now uses the cuda implementation of NMS from the torchvision package, which is faster than both the NMS and NMSFast implementations. Simply use NMS')
+    import warnings
+    warnings.warn(
+        'Lightnet now uses the cuda implementation of NMS from the torchvision package, which is faster than both the NMS and NMSFast implementations. Simply use NMS',
+        category=DeprecationWarning,
+        stacklevel=2,
+    )
     return NMS(*args, **kwargs)
 
 
