@@ -43,7 +43,7 @@ class ReverseCrop(nn.Module):
             scale, pad = self._get_params(net_w, net_h, im_w, im_h)
             return self._transform(boxes.copy(), scale, pad)
 
-        return boxes.groupby('image').apply(self._apply_transform)
+        return boxes.groupby('image', group_keys=False).apply(self._apply_transform)
 
     def _apply_transform(self, boxes):
         net_w, net_h = self.network_size
@@ -120,7 +120,7 @@ class ReverseLetterbox(nn.Module):
             scale, pad = self._get_params(net_w, net_h, im_w, im_h)
             return self._transform(boxes.copy(), scale, pad)
 
-        return boxes.groupby('image').apply(self._apply_transform)
+        return boxes.groupby('image', group_keys=False).apply(self._apply_transform)
 
     def _apply_transform(self, boxes):
         net_w, net_h = self.network_size
@@ -195,7 +195,7 @@ class ReversePad(nn.Module):
             self._get_params(im_w, im_h)
             return self._transform(boxes.copy(), self.pad)
 
-        return boxes.groupby('image').apply(self._apply_transform)
+        return boxes.groupby('image', group_keys=False).apply(self._apply_transform)
 
     def _get_params(self, im_w, im_h):
         if isinstance(self.network_factor, int):
