@@ -3,7 +3,7 @@
 #   Copyright EAVISE
 #
 import random
-import collections
+from collections.abc import Sequence
 import numpy as np
 import torch
 import torch.nn.functional as F
@@ -72,12 +72,11 @@ class Crop(ImageAnnoTransform):
     @torch.jit.unused
     def _tf_pil(self, img):
         if self._scale != 1:
-            bands = img.split()
-            bands = [
-                b.resize((int(self._scale*self._img_width+0.5), int(self._scale*self._img_height+0.5)), resample=Image.BILINEAR)
-                for b in bands
-            ]
-            img = Image.merge(img.mode, bands)
+            img = img.resize(
+                (int(self._scale*self._img_width+0.5), int(self._scale*self._img_height+0.5)),
+                resample=Image.BILINEAR,
+                reducing_gap=3,
+            )
 
         if self._crop is not None:
             img = img.crop(self._crop)
@@ -194,12 +193,11 @@ class Letterbox(ImageAnnoTransform):
     @torch.jit.unused
     def _tf_pil(self, img):
         if self._scale != 1:
-            bands = img.split()
-            bands = [
-                b.resize((int(self._scale*self._img_width+0.5), int(self._scale*self._img_height+0.5)), resample=Image.BILINEAR)
-                for b in bands
-            ]
-            img = Image.merge(img.mode, bands)
+            img = img.resize(
+                (int(self._scale*self._img_width+0.5), int(self._scale*self._img_height+0.5)),
+                resample=Image.BILINEAR,
+                reducing_gap=3,
+            )
 
         if self._pad != (0, 0, 0, 0):
             channels = len(img.getbands())
@@ -413,7 +411,7 @@ class FitAnno(AnnoTransform):
         #   - Computes: `np.nan_to_num(nan) = 0`
         with np.errstate(divide='ignore', invalid='ignore'):
             if self.filter:
-                if isinstance(self.filter_threshold, collections.Sequence):
+                if isinstance(self.filter_threshold, Sequence):
                     mask = (
                         ((crop_width / anno['width'].values) >= self.filter_threshold[0])
                         & ((crop_height / anno['height'].values) >= self.filter_threshold[1])
