@@ -5,7 +5,7 @@
 import logging
 import signal
 from abc import ABCMeta, abstractmethod
-from collections import Sequence
+from collections.abc import Sequence
 from enum import Flag, auto
 from functools import wraps, update_wrapper
 from itertools import chain
@@ -247,7 +247,7 @@ class Engine(metaclass=engine_meta):
         There are 4 different decorator functions to register a hook.
         An optional square bracket index/slice notation allows you to specify different iteration ranges for the hooks.
 
-        >>> class TrainingEngine(ln.engine.Engine):
+        >>> class TrainingEngine(ln.engine.Engine):     # doctest: +SKIP
         ...     def start(self):
         ...         pass
         ...
@@ -385,14 +385,12 @@ class Engine(metaclass=engine_meta):
         self.__check_attr()
         self.start()
 
-        log.info('Start training')
         self.network.train()
 
         idx = 0
         while True:
             # Check if we need to stop training
             if self.quit() or self.sigint:
-                log.info('Reached quitting criteria')
                 return
 
             # Epoch Start
@@ -419,7 +417,6 @@ class Engine(metaclass=engine_meta):
 
                 # Check if we need to stop training
                 if self.quit() or self.sigint:
-                    log.info('Reached quitting criteria')
                     return
 
             # Epoch End
