@@ -2,7 +2,7 @@
 #   Learning Rate Scheduling
 #   Copyright EAVISE
 #
-from collections import Iterable
+from collections.abc import Iterable
 import itertools
 import torch
 import logging
@@ -12,7 +12,12 @@ log = logging.getLogger(__name__)
 
 
 def SchedulerCompositor(*args, last_epoch=-1):
-    log.deprecated('SchedulerCompositor is deprecated for the new MultiLRScheduler')
+    import warnings
+    warnings.warn(
+        'SchedulerCompositor is deprecated for the new MultiLRScheduler',
+        category=DeprecationWarning,
+        stacklevel=2,
+    )
     epoch, sched = zip(*args)
     return MultiLRScheduler(sched, epoch[1:], True, last_epoch)
 
