@@ -2,13 +2,12 @@
 #   Cornernet Squeeze model
 #   Copyright EAVISE
 #
-import logging
+import warnings
 import re
 import torch.nn as nn
 import lightnet.network as lnn
 
 __all__ = ['CornernetSqueeze']
-log = logging.getLogger('lightnet.models')
 
 
 class CornernetSqueeze(lnn.module.Lightnet):
@@ -79,7 +78,7 @@ class CornernetSqueeze(lnn.module.Lightnet):
         input_channels=3,
         inference_only=False,
     ):
-        log.experimental('CornernetSqueeze is still in development. Use at your own risk!')
+        warnings.warn('CornernetSqueeze is still in development. Use at your own risk!', category=FutureWarning)
 
         self.num_classes = num_classes
         self.input_channels = input_channels
@@ -102,7 +101,7 @@ class CornernetSqueeze(lnn.module.Lightnet):
 
     def __init_weights__(self, name, mod):
         if name.endswith('output.heatmap.4_conv'):
-            nn.init.kaiming_normal_(mod.weight, mode='fan_out', nonlinearity='relu')
+            nn.init.kaiming_normal_(mod.weight, nonlinearity='relu')
             nn.init.constant_(mod.bias, -2.19)
             return True
 
