@@ -79,7 +79,7 @@ class TinyYoloV2(lnn.module.Darknet):
 
     def __init_weights__(self, name, mod):
         if isinstance(mod, nn.Conv2d):
-            nn.init.kaiming_normal_(mod.weight, a=0.1, mode='fan_out')
+            nn.init.kaiming_normal_(mod.weight, nonlinearity='leaky_relu', a=0.1)
             if mod.bias is not None:
                 nn.init.constant_(mod.bias, 0)
             return True
