@@ -138,7 +138,7 @@ class YoloFusion(lnn.module.Lightnet):
                 fuse = len(l) + 1
             i += len(l)
 
-            self.layers.append(lnn.layer.Fusion(l, fuse))
+            self.layers.append(lnn.layer.FusionSequential(l, fuse))
 
         if self.fuse_seq is None:
             raise ValueError(f'Fuse_layer too high [{fuse_layer}/{sum(len(l) for l in layer_list)+1}]')
@@ -152,7 +152,7 @@ class YoloFusion(lnn.module.Lightnet):
                 ]),
             ))
         else:
-            self.layers.append(lnn.layer.Fusion(
+            self.layers.append(lnn.layer.FusionSequential(
                 OrderedDict([
                     ('P1_convbatch',    lnn.layer.Conv2dBatchReLU(512, 64, 1, 1, 0, relu=relu, momentum=momentum)),
                     ('P2_reorg',        lnn.layer.Reorg(2)),
@@ -164,7 +164,7 @@ class YoloFusion(lnn.module.Lightnet):
 
     def __init_weights__(self, name, mod):
         if isinstance(mod, nn.Conv2d):
-            nn.init.kaiming_normal_(mod.weight, a=0.1, mode='fan_out')
+            nn.init.kaiming_normal_(mod.weight, nonlinearity='leaky_relu', a=0.1)
             if mod.bias is not None:
                 nn.init.constant_(mod.bias, 0)
             return True
