@@ -3,8 +3,11 @@
 #   Copyright EAVISE
 #
 
+from ._conv import *
 from ._cornernet import *
 from ._darknet import *
+from ._deform import *
+from ._fpn import *
 from ._fusion import *
 from ._hourglass import *
 from ._mobilenet import *
