@@ -36,7 +36,12 @@ class Flatten(nn.Module):
         torch.Size([2400])
     """
     def __new__(cls, batch=True):
-        log.deprecated_once('Flatten is deprecated in favor for the equivalent pytorch version (torch.nn.Flatten).')
+        import warnings
+        warnings.warn(
+            'Flatten is deprecated in favor for the equivalent pytorch version (torch.nn.Flatten).',
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
         return nn.Flatten(1 if batch else 0)
 
 
