@@ -443,5 +443,10 @@ class FusionModule(nn.Module):
 
 
 def Fusion(*args, **kwargs):
-    log.deprecated_once('Fusion is renamed to FusionSequential.')
+    import warnings
+    warnings.warn(
+        'Fusion is renamed to FusionSequential.',
+        category=DeprecationWarning,
+        stacklevel=2,
+    )
     return FusionSequential(*args, **kwargs)
