@@ -2,7 +2,6 @@
 #   Utility layers
 #   Copyright EAVISE
 #
-import copy
 import logging
 import torch
 import torch.nn as nn
@@ -94,24 +93,17 @@ class FeatureExtractor(nn.Module):
         self.module = module
         self.selection = tuple(str(s) for s in selection)
         self.return_selection = return_selection
-        self.features = {}
 
         # Register hooks
         self._register_hooks()
 
-        # Check if selection is found
-        registered = set(self.features.keys())
-        notfound = tuple(s not in registered for s in self.selection)
-        if any(notfound):
-            log.debug('Existing layer names: %s', tuple(n for n, m in self.module.named_modules()))
-            notfound = tuple(s for (nf, s) in zip(notfound, self.selection) if nf)
-            raise ValueError(f'Selected layers not found in module: {notfound}')
-
     def extra_repr(self):
         return f'selection=[{", ".join(self.selection)}], return={self.return_selection}'
 
     def forward(self, x):
-        self.features = {sel: None for sel in self.selection}
+        for name in self.selection:
+            self.module.get_submodule(name).feature_extractor = None
+
         x = self.module(x)
 
         if self.return_selection:
@@ -120,35 +112,19 @@ class FeatureExtractor(nn.Module):
             return x
 
     def _register_hooks(self):
+        def save_feature_hook(layer, inp, out):
+            layer.feature_extractor = out.clone()
+
         self.hook_handles = []
-        for name, mod in self.module.named_modules():
-            if name in self.selection:
-                self.features[name] = None
-                self.hook_handles.append(mod.register_forward_hook(self._save_feat_hook(name)))
+        for name in self.selection:
+            mod = self.module.get_submodule(name)
+            mod.register_buffer('feature_extractor', None, persistent=False)
+            self.hook_handles.append(mod.register_forward_hook(save_feature_hook))
 
-    def __deepcopy__(self, memo):
-        # Remove hooks
-        for handle in self.hook_handles:
-            handle.remove()
-        del self.hook_handles
-
-        # Deep copy
-        cls = self.__class__
-        result = cls.__new__(cls)
-        memo[id(self)] = result
-        for k, v in self.__dict__.items():
-            setattr(result, k, copy.deepcopy(v, memo))
-
-        # Reset Hooks
-        self._register_hooks()
-        result._register_hooks()
-
-        return result
-
-    def _save_feat_hook(self, layername):
-        def feat_hook(layer, inp, out):
-            self.features[layername] = out.clone()
-        return feat_hook
+    @property
+    def features(self):
+        """ Return dictionary with extracted feature maps. """
+        return {name: self.module.get_submodule(name).feature_extractor for name in self.selection}
 
 
 class Parallel(nn.Sequential):
@@ -483,7 +459,12 @@ class SequentialSelect(nn.Sequential):
         torch.Size([1, 32, 10, 10])
     """
     def __init__(self, selection, return_selection, *args):
-        log.deprecated_once('SequentialSelect is deprecated in favor for the more powerfull FeatureExtractor.')
+        import warnings
+        warnings.warn(
+            'SequentialSelect is deprecated in favor for the more powerfull FeatureExtractor.',
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
         super().__init__(*args)
 
         self.return_selection = return_selection
