@@ -3,9 +3,9 @@
 #   Copyright EAVISE
 #
 import logging
+import pandas as pd
 import torch
 from lightnet.util import iou_cwh, iou_wh
-from lightnet._imports import pd
 from lightnet._compat import meshgrid_kw
 from ._base import Loss, MultiScale
 
@@ -61,7 +61,12 @@ class RegionLoss(Loss):
 
     @property
     def loss(self):
-        log.deprecated_once('The "loss" attribute is deprecated in favor for "loss_total"')
+        import warnings
+        warnings.warn(
+            'The "loss" attribute is deprecated in favor for "loss_total"',
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
         return self.loss_total
 
     def extra_repr(self):
@@ -121,7 +126,7 @@ class RegionLoss(Loss):
         coord[:, :, 2:4] = output[:, :, 2:4]            # tw,th
         conf = output[:, :, 4].sigmoid()
         if nC > 1:
-            cls = output[:, :, 5:].reshape(nB*nA, nC, nPixels).transpose(1, 2).reshape(-1, nC)
+            cls = output[:, :, 5:].transpose(-1, -2).reshape(-1, nC)
 
         with torch.no_grad():
             # Create prediction boxes
@@ -130,16 +135,19 @@ class RegionLoss(Loss):
             lin_y, lin_x = torch.meshgrid(torch.arange(nH), torch.arange(nW), **meshgrid_kw)
             lin_x = lin_x.reshape(-1).to(device)
             lin_y = lin_y.reshape(-1).to(device)
-            anchor_wh = self.anchors.reshape(nA, 2, 1).to(device)
+            anchor_w = self.anchors[:, 0].contiguous().view(nA, 1).to(device)
+            anchor_h = self.anchors[:, 1].contiguous().view(nA, 1).to(device)
 
             # Compute max possible width/height network output, before the computed width/height would reach inf
             max_value = torch.tensor(1e35, dtype=pred_boxes.dtype, device=pred_boxes.device)
-            max_value = (max_value / anchor_wh.max()).log().floor()
+            max_w = (max_value / anchor_w.max()).log().floor()
+            max_h = (max_value / anchor_h.max()).log().floor()
 
             # Get prediction coordinates
             pred_boxes[:, 0] = (coord[:, :, 0].detach() + lin_x).view(-1)
             pred_boxes[:, 1] = (coord[:, :, 1].detach() + lin_y).view(-1)
-            pred_boxes[:, 2:4] = (coord[:, :, 2:4].detach().clamp(max=max_value).exp() * anchor_wh).view(-1, 2)
+            pred_boxes[:, 2] = (coord[:, :, 2].detach().clamp(max=max_w).exp() * anchor_w).view(-1)
+            pred_boxes[:, 3] = (coord[:, :, 3].detach().clamp(max=max_h).exp() * anchor_h).view(-1)
             pred_boxes = pred_boxes.cpu()
 
             # Get target values
@@ -149,9 +157,8 @@ class RegionLoss(Loss):
             tcoord = tcoord.to(device)
             tconf = tconf.to(device)
             if nC > 1:
-                tcls = tcls[cls_mask].view(-1).long().to(device)
-                cls_mask = cls_mask.view(-1, 1).repeat(1, nC).to(device)
-                cls = cls[cls_mask].view(-1, nC)
+                tcls[~cls_mask] = -100                  # -100: ignored index CEL
+                tcls = tcls.view(-1).long().to(device)
 
         # Confidence loss
         if self.object_scale == 0 and self.noobject_scale == 0:
@@ -172,6 +179,7 @@ class RegionLoss(Loss):
             self.loss_class = torch.tensor([0.0] * nB, device=device)
         else:
             self.loss_class = torch.nn.functional.cross_entropy(cls, tcls, reduction='none')
+            self.loss_class = self.loss_class.view(nB, -1)
             self.loss_class = self.class_scale * self.loss_class.sum(dim=tuple(range(1, self.loss_class.ndim)))
 
         # Total loss
@@ -203,7 +211,7 @@ class RegionLoss(Loss):
         tcls = torch.zeros(nB, nA, nH, nW, requires_grad=False)
 
         if self.training and self.seen < self.coord_prefill:
-            coord_mask.fill_(.01 / self.coord_scale)
+            coord_mask.fill_((.01 / self.coord_scale) ** 0.5)
             tcoord[:, :, 0].fill_(0.5)
             tcoord[:, :, 1].fill_(0.5)
 
@@ -267,7 +275,7 @@ class RegionLoss(Loss):
         tcls = torch.zeros(nB, nA, nH, nW)
 
         if self.training and self.seen < self.coord_prefill:
-            coord_mask.fill_(.01 / self.coord_scale)
+            coord_mask.fill_((.01 / self.coord_scale) ** 0.5)
             tcoord[:, :, 0].fill_(0.5)
             tcoord[:, :, 1].fill_(0.5)
 
