@@ -6,7 +6,8 @@ import inspect
 import logging
 import re
 from abc import abstractmethod
-from collections import OrderedDict, Iterable
+from collections import OrderedDict
+from collections.abc import Iterable
 from operator import attrgetter
 import torch
 import torch.nn as nn
@@ -46,7 +47,7 @@ class Lightnet(nn.Module):
         The default implementation intializes the following layers:
 
         - :class:`~torch.nn.Conv2d` |br|
-          Weights get initialized with a kaiming_normal distribution in 'fan_out' mode and with 'relu' as the nonlinearity.
+          Weights get initialized with a kaiming_normal distribution in 'fan_in' mode and with 'relu' as the nonlinearity.
           If there is a bias, it gets initialized with a constant value of 0.
         - :class:`~torch.nn.BatchNorm2d`, :class:`~torch.nn.GroupNorm` |br|
           Weights get initialized with a constant value of 1, bias with a constant value of 0.
@@ -67,7 +68,7 @@ class Lightnet(nn.Module):
             so that other layers get this default behaviour.
         """
         if isinstance(mod, (DeformableConv2d, ModulatedDeformableConv2d)):
-            nn.init.kaiming_normal_(mod.conv.weight, mode='fan_out', nonlinearity='relu')
+            nn.init.kaiming_normal_(mod.conv.weight, nonlinearity='relu')
             if mod.conv.bias is not None:
                 nn.init.constant_(mod.conv.bias, 0)
 
@@ -77,7 +78,7 @@ class Lightnet(nn.Module):
 
             return True
         elif isinstance(mod, nn.Conv2d):
-            nn.init.kaiming_normal_(mod.weight, mode='fan_out', nonlinearity='relu')
+            nn.init.kaiming_normal_(mod.weight, nonlinearity='relu')
             if mod.bias is not None:
                 nn.init.constant_(mod.bias, 0)
             return True
@@ -196,7 +197,12 @@ class Lightnet(nn.Module):
         .. deprecated:: 3.0.0
             |br| This method is being deprecated in favor of our overloaded :class:`~lightnet.network.modules.Lightnet.modules` method.
         """
-        log.deprecated_once('The `layer_loop` method is being deprecated. Use the overloaded `modules` method instead.')
+        import warnings
+        warnings.warn(
+            'The `layer_loop` method is being deprecated. Use the overloaded `modules` method instead.',
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
         if mod is not None:
             raise ValueError('Setting a base module is not supported anymore')
 
@@ -208,37 +214,81 @@ class Lightnet(nn.Module):
         .. deprecated:: 3.0.0
             |br| This method is being deprecated in favor of our overloaded :class:`~lightnet.network.modules.Lightnet.named_modules` method.
         """
-        log.deprecated_once('The `named_layer_loop` method is being deprecated. Use the overloaded `named_modules` method instead.')
+        import warnings
+        warnings.warn(
+            'The `named_layer_loop` method is being deprecated. Use the overloaded `named_modules` method instead.',
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
         if mod is not None:
             raise ValueError('Setting a base module is not supported anymore')
 
         return self.named_modules(layers, prefix=prefix)
 
+    def __str__(self):
+        """ Shorter version than default PyTorch one. """
+        args = list(inspect.signature(self.__class__.__init_module__).parameters.keys())
+        args.remove('self')
+
+        string = self.__class__.__name__ + '('
+        for i, arg in enumerate(args):
+            if i > 0:
+                string += ', '
+            val = getattr(self, arg, '?')
+            string += f'{arg}={val}'
+        string += ')'
+
+        return string
+
+    @property
+    def __name__(self):
+        return self.__class__.__name__
+
+    def save(self, weights_file, remap=None):
+        """ This function will save the weights to a file.
+
+        Args:
+            weights_file (str):
+                Path to file
+            remap (callable or list, optional):
+                Remapping of the weights, see :func:`~lightnet.network.module.Lightnet.weight_remapping`; Default **None**
+        """
+        if remap is not None:
+            state = self.weight_remapping(self.state_dict(), remap)
+            remap = ' remapped'
+            if '_LN_MODEL_VERSION' in state:
+                del state['_LN_MODEL_VERSION']
+        else:
+            state = self.state_dict()
+            remap = ''
+
+        torch.save(state, weights_file)
+        log.info('Saved%s weights as %s', remap, weights_file)
+
     def load(self, weights_file, remap=None, strict=True):
         """ This function will load the weights from a file.
         It also allows to load in a weights file with only a part of the weights in.
 
         Args:
-            weights_file (str): path to file
-            remap (callable or list, optional): Remapping of the weights, see :func:`~lightnet.network.module.Lightnet.weight_remapping`; Default **None**
-            strict (Boolean, optional): Whether the weight file should contain all layers of the model; Default **True**
+            weights_file (str):
+                path to file
+            remap (callable or list, optional):
+                Remapping of the weights, see :func:`~lightnet.network.module.Lightnet.weight_remapping`; Default **None**
+            strict (Boolean, optional):
+                Whether the weight file should contain all layers of the model; Default **True**
 
         Note:
             This function will load the weights to CPU,
             so you should use ``network.to(device)`` afterwards to send it to the device of your choice.
         """
         state = torch.load(weights_file, 'cpu')
-        model_version = state.pop('_LN_MODEL_VERSION', 0)
 
+        remap = ''
         if remap is not None:
-            if model_version != getattr(self, 'MODEL_VERSION', 0):
-                log.error('Your weight file does not match the model version. We are not attempting automatic version remapping, as a remapping method has been specified.')
-
             state = self.weight_remapping(state, remap)
             remap = ' remapped'
-        else:
-            remap = ''
-            state = self._remap_model_version(state, model_version)
+            if '_LN_MODEL_VERSION' in state:
+                del state['_LN_MODEL_VERSION']
 
         log.info('Loading%s weights from file [%s]', remap, weights_file)
         if not strict and state.keys() != self.state_dict().keys():
@@ -248,12 +298,13 @@ class Lightnet(nn.Module):
 
     def load_pruned(self, weights_file, strict=True):
         """ This function will load pruned weights from a file.
-        It also allows to load a weights file,
-        which contains less channels in a convolution than orginally defined in the network.
+        It also allows to load a weights file, which contains less channels in a convolution than orginally defined in the network.
 
         Args:
-            weights_file (str): path to file
-            strict (Boolean, optional): Whether the weight file should contain all layers of the model; Default **True**
+            weights_file (str):
+                Path to file
+            strict (Boolean, optional):
+                Whether the weight file should contain all layers of the model; Default **True**
 
         Note:
             This function will load the weights to CPU,
@@ -299,7 +350,28 @@ class Lightnet(nn.Module):
         # Load weights
         if not strict and state.keys() != keys:
             log.warning('Modules not matching, performing partial update')
-        self.load_state_dict(state, strict=strict)
+
+        # We already remapped versions, so run super load_state_dict straight away
+        super().load_state_dict(state, strict=strict)
+
+    def state_dict(self, **kwargs):
+        state = super().state_dict(**kwargs)
+        state['_LN_MODEL_VERSION'] = getattr(self, 'MODEL_VERSION', 0)
+        return state
+
+    def load_state_dict(self, state_dict, strict=True):
+        if '_LN_MODEL_VERSION' not in state_dict:
+            try:
+                # Remapped weights do not contain MODEL_VERSION
+                return super().load_state_dict(state_dict, strict=strict)
+            except RuntimeError:
+                # Attempt automatic version adaptation from lightnet < 3
+                state_dict = self._remap_model_version(state_dict, 0)
+                return super().load_state_dict(state_dict, strict=strict)
+        else:
+            state_version = state_dict.pop('_LN_MODEL_VERSION')
+            state_dict = self._remap_model_version(state_dict, state_version)
+            return super().load_state_dict(state_dict, strict=strict)
 
     def _remap_model_version(self, state, version):
         model_version = getattr(self, 'MODEL_VERSION', 0)
@@ -318,7 +390,7 @@ class Lightnet(nn.Module):
                     f'but the automatic version remapping is not detected for this model ({version-1} -> {model_version}).',
                 )
             else:
-                log.deprecated(
+                log.warning(
                     'Your weight file is using an old format. '
                     'We are automatically adapting them for now, but make sure to resave your weights.',
                 )
@@ -327,45 +399,6 @@ class Lightnet(nn.Module):
 
         return state
 
-    def save(self, weights_file, remap=None):
-        """ This function will save the weights to a file.
-
-        Args:
-            weights_file (str): path to file
-            remap (callable or list, optional): Remapping of the weights, see :func:`~lightnet.network.module.Lightnet.weight_remapping`; Default **None**
-        """
-        if remap is not None:
-            state = self.weight_remapping(self.state_dict(), remap)
-            remap = ' remapped'
-        else:
-            state = self.state_dict()
-            remap = ''
-
-        model_version = getattr(self, 'MODEL_VERSION', 0)
-        state['_LN_MODEL_VERSION'] = model_version
-
-        torch.save(state, weights_file)
-        log.info('Saved%s weights as %s', remap, weights_file)
-
-    def __str__(self):
-        """ Shorter version than default PyTorch one. """
-        args = list(inspect.signature(self.__class__.__init_module__).parameters.keys())
-        args.remove('self')
-
-        string = self.__class__.__module__ + '.' + self.__class__.__name__ + '('
-        for i, arg in enumerate(args):
-            if i > 0:
-                string += ', '
-            val = getattr(self, arg, '?')
-            string += f'{arg}={val}'
-        string += ')'
-
-        return string
-
-    @property
-    def __name__(self):
-        return self.__class__.__name__
-
     @staticmethod
     def weight_remapping(weights, remap):
         r""" This function is used to remap the keys of a ``state_dict``.
