@@ -51,6 +51,14 @@ class anchor_meta(type):
             ((1.3221, 1.73145), (3.19275, 4.00944), (5.05587, 8.09892), (9.47112, 4.84053), (11.2364, 10.0071)),
         )
 
+    @property
+    def YoloV2_COCO(cls):
+        """ YoloV2 Anchors for the COCO dataset. """
+        return Anchors.from_darknet(
+            32,
+            ((0.57273, 0.677385), (1.87446, 2.06253), (3.33843, 5.47434), (7.88282, 3.52778), (9.77052, 9.16828)),
+        )
+
     @property
     def TinyYoloV3_COCO(cls):
         """ Tiny YoloV3 Anchors for the MS COCO dataset. """
@@ -653,7 +661,7 @@ def check_anchors(
             3        4979.0  66.865035  12.436371  15.426576  60.468238  66.713623  74.787686  99.831313
             4        4288.0  73.143479   9.584754  49.041309  65.662809  72.233269  79.995130  98.806671
 
-        We now compare with our own computed values (see :func:`~lightnet.utils.compute_anchors`).
+        We now compare with our own computed values (see :func:`~lightnet.util.compute_anchors`).
 
         .. doctest::
             :options: +SKIP
@@ -776,7 +784,7 @@ def compute_anchors(
             Extra arguments that are passed to the constructor of sklearn.cluster.KMeans; Default **{}**
 
     Returns:
-        lightnet.utils.Anchors: The computed anchors
+        lightnet.util.Anchors: The computed anchors
 
     Warning:
         Darknet anchors are inconsistent, because they get specified differently depending on whether the model is multiscale or not.
@@ -886,9 +894,9 @@ def fit_annos(anno, fit, identify, columns=None):
             return df[columns]
 
     if tqdm:
-        anno_size = anno.groupby('image').progress_apply(_fit)
+        anno_size = anno.groupby('image', group_keys=False).progress_apply(_fit)
     else:
-        anno_size = anno.groupby('image').apply(_fit)
+        anno_size = anno.groupby('image', group_keys=False).apply(_fit)
 
     anno = anno.copy()
     for c in columns:
