@@ -74,7 +74,7 @@ def input_tensor():
 @pytest.mark.parametrize('network', classification_networks)
 def test_classification_cpu(network, input_tensor):
     uut = getattr(ln.models, network)(10).eval()
-    it = input_tensor(uut.inner_stride * 3)
+    it = input_tensor(uut.inner_stride)
 
     output_tensor = uut(it)
     assert output_tensor.dim() == 2
@@ -87,7 +87,7 @@ def test_classification_cpu(network, input_tensor):
 @pytest.mark.skipif(not torch.cuda.is_available(), reason='CUDA not available')
 def test_classification_cuda(network, input_tensor):
     uut = getattr(ln.models, network)(10).to('cuda')
-    it = input_tensor(uut.inner_stride * 3, batch=2).to('cuda')
+    it = input_tensor(uut.inner_stride, batch=2).to('cuda')
 
     output_tensor = uut(it)
     assert output_tensor.dim() == 2
